Creates a table of URLs provided by the Cadastre of Navarre ATOM INSPIRE service for downloading addresses by municipality.
Usage
catrnav_atom_get_address_db_all(
cache = TRUE,
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE
)Arguments
- cache
A logical value indicating whether to use cached files. Defaults to
TRUE.- update_cache
Logical. Should the cached file be refreshed? Defaults to
FALSE. When set toTRUE, it forces a new download.- cache_dir
Path to a cache directory. On
NULL, the function stores cached files in a temporary directory (seebase::tempdir()).- verbose
Logical. If
TRUE, displays informational messages.
Value
A tibble with the requested information in the following columns:
munic: Municipality name and cadastral code.url: ATOM URL for the corresponding municipality.date: Reference date of the data.
See also
Download data from the ATOM INSPIRE service:
catrnav_atom_get_address(),
catrnav_atom_get_buildings(),
catrnav_atom_get_buildings_db_all(),
catrnav_atom_get_parcels(),
catrnav_atom_get_parcels_db_all(),
catrnav_atom_search_munic()
Work with cadastral addresses:
catrnav_atom_get_address(),
catrnav_wfs_get_address_bbox(),
catrnav_wms_get_layer()
Examples
catrnav_atom_get_address_db_all()
#> # A tibble: 272 × 3
#> munic url date
#> <chr> <chr> <date>
#> 1 001 Abáigar https://filescartografia.navarra… 2026-04-14
#> 2 002 Abárzuza / Abartzuza https://filescartografia.navarra… 2026-04-14
#> 3 003 Abaurregaina / Abaurrea Alta https://filescartografia.navarra… 2026-04-14
#> 4 004 Abaurrepea / Abaurrea Baja https://filescartografia.navarra… 2026-04-14
#> 5 005 Aberin https://filescartografia.navarra… 2026-04-14
#> 6 006 Ablitas https://filescartografia.navarra… 2026-04-14
#> 7 007 Adiós https://filescartografia.navarra… 2026-04-14
#> 8 008 Aguilar de Codés https://filescartografia.navarra… 2026-04-14
#> 9 009 Aibar / Oibar https://filescartografia.navarra… 2026-04-14
#> 10 010 Altsasu / Alsasua https://filescartografia.navarra… 2026-04-14
#> # ℹ 262 more rows