ATOM INSPIRE: download all buildings for a municipality
Source:R/atom-bu.R
catrnav_atom_get_buildings.RdDownloads spatial data for all buildings in a municipality using the ATOM INSPIRE service provided by the Cadastre of Navarre.
Usage
catrnav_atom_get_buildings(
munic,
cache = TRUE,
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE
)Arguments
- munic
Municipality name, partial name or cadastral code. Use
catrnav_atom_search_munic()to search for available municipalities.- cache
A logical value indicating whether to use cached files. Defaults to
TRUE.- update_cache
Logical. Should the cached file be refreshed? Defaults to
FALSE. When set toTRUE, it forces a new download.- cache_dir
Path to a cache directory. On
NULL, the function stores cached files in a temporary directory (seebase::tempdir()).- verbose
Logical. If
TRUE, displays informational messages.
Value
An sf object, or NULL if the data cannot be
retrieved.
See also
Download data from the ATOM INSPIRE service:
catrnav_atom_get_address(),
catrnav_atom_get_address_db_all(),
catrnav_atom_get_buildings_db_all(),
catrnav_atom_get_parcels(),
catrnav_atom_get_parcels_db_all(),
catrnav_atom_search_munic()
Work with cadastral buildings:
catrnav_atom_get_buildings_db_all(),
catrnav_wfs_get_buildings_bbox(),
catrnav_wms_get_layer()