Skip to contents

Creates a tibble of URLs provided by the Cadastre of Navarre ATOM INSPIRE service for downloading buildings by municipality.

Usage

catrnav_atom_get_buildings_db_all(
  cache = deprecated(),
  update_cache = FALSE,
  cache_dir = NULL,
  verbose = FALSE
)

Arguments

cache

[Deprecated] This argument is no longer supported because results are always cached.

update_cache

Logical. Whether to refresh the cached file. Defaults to FALSE.

cache_dir

Path to a cache directory. If NULL, uses the configured cache or a directory inside base::tempdir(). See catrnav_set_cache_dir().

verbose

Logical. Whether to display informational messages.

Value

A tibble with the following columns. Returns NULL if the data cannot be retrieved.

  • munic: Municipality name and cadastral code.

  • url: ATOM URL for the corresponding municipality.

  • date: Reference timestamp of the data in UTC.

Examples

catrnav_atom_get_buildings_db_all()
#> # A tibble: 281 × 3
#>    munic                            url                      date               
#>    <chr>                            <chr>                    <dttm>             
#>  1 001 Abáigar                      https://filescartografi… 2026-06-30 13:45:03
#>  2 002 Abárzuza / Abartzuza         https://filescartografi… 2026-06-30 13:45:03
#>  3 003 Abaurregaina / Abaurrea Alta https://filescartografi… 2026-06-30 13:45:03
#>  4 004 Abaurrepea / Abaurrea Baja   https://filescartografi… 2026-06-30 13:45:03
#>  5 005 Aberin                       https://filescartografi… 2026-06-30 13:45:03
#>  6 006 Ablitas                      https://filescartografi… 2026-06-30 13:45:03
#>  7 007 Adiós                        https://filescartografi… 2026-06-30 13:45:03
#>  8 008 Aguilar de Codés             https://filescartografi… 2026-06-30 13:45:03
#>  9 009 Aibar / Oibar                https://filescartografi… 2026-06-30 13:45:03
#> 10 010 Altsasu / Alsasua            https://filescartografi… 2026-06-30 13:45:03
#> # ℹ 271 more rows