Determines whether an example should run based on CRAN status and network availability.
Value
A logical value. Returns TRUE if online and not
running on CRAN, FALSE otherwise.
Determines whether an example should run based on CRAN status and network availability.
A logical value. Returns TRUE if online and not
running on CRAN, FALSE otherwise.
Site built with pkgdown 2.2.1.
Template rostemplate by dieghernan, based on Universal Theme for Hugo.