Skip to contents

Downloads spatial data for all addresses in a municipality using the ATOM INSPIRE service provided by the Cadastre of Navarre.

Usage

catrnav_atom_get_address(
  munic,
  cache = TRUE,
  update_cache = FALSE,
  cache_dir = NULL,
  verbose = FALSE
)

Arguments

munic

Municipality name, partial name or cadastral code. Use catrnav_atom_search_munic() to search for available municipalities.

cache

A logical value indicating whether to use cached files. Defaults to TRUE.

update_cache

Logical. Should the cached file be refreshed? Defaults to FALSE. When set to TRUE, it forces a new download.

cache_dir

Path to a cache directory. On NULL, the function stores cached files in a temporary directory (see base::tempdir()).

verbose

Logical. If TRUE, displays informational messages.

Value

An sf object, or NULL if the data cannot be retrieved.

Examples


s <- catrnav_atom_get_address("Tudela")

library(ggplot2)

ggplot(s) +
  geom_sf() +
  labs(
    title = "Addresses",
    subtitle = "Tudela"
  )