ATOM INSPIRE: Download all the cadastral addresses of a municipality
Source:R/atom_ad.R
catrnav_atom_get_address.RdGet the spatial data of all the cadastral addresses belonging to a single municipality using the INSPIRE ATOM service.
Usage
catrnav_atom_get_address(
munic,
cache = TRUE,
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE
)Arguments
- munic
Municipality to extract. It can be a part of a string or the cadastral code. See catrnav_atom_get_address_db_all.
- cache
A logical value indicating whether to use caching. Default is
TRUE. See About caching section oncatrnav_set_cache_dir().- update_cache
A logical value indicating whether to update the cache. Default is
FALSE. When set toTRUE, forces a fresh download of the source file.- cache_dir
A path to a cache directory. On missing value the function stores the cached files in a temporary dir (see
base::tempdir()).- verbose
Logical, displays information. Useful for debugging, default is
FALSE.
Value
A sf object.