Skip to contents

Creates a table of URLs provided by the Cadastre of Navarre ATOM INSPIRE service for downloading buildings by municipality.

Usage

catrnav_atom_get_buildings_db_all(
  cache = TRUE,
  update_cache = FALSE,
  cache_dir = NULL,
  verbose = FALSE
)

Arguments

cache

A logical value indicating whether to use cached files. Defaults to TRUE.

update_cache

Logical. Should the cached file be refreshed? Defaults to FALSE. When set to TRUE, it forces a new download.

cache_dir

Path to a cache directory. On NULL, the function stores cached files in a temporary directory (see base::tempdir()).

verbose

Logical. If TRUE, displays informational messages.

Value

A tibble with the requested information in the following columns:

  • munic: Municipality name and cadastral code.

  • url: ATOM URL for the corresponding municipality.

  • date: Reference date of the data.

Examples

catrnav_atom_get_buildings_db_all()
#> # A tibble: 281 × 3
#>    munic                            url                               date      
#>    <chr>                            <chr>                             <date>    
#>  1 001 Abáigar                      https://filescartografia.navarra… 2026-06-30
#>  2 002 Abárzuza / Abartzuza         https://filescartografia.navarra… 2026-06-30
#>  3 003 Abaurregaina / Abaurrea Alta https://filescartografia.navarra… 2026-06-30
#>  4 004 Abaurrepea / Abaurrea Baja   https://filescartografia.navarra… 2026-06-30
#>  5 005 Aberin                       https://filescartografia.navarra… 2026-06-30
#>  6 006 Ablitas                      https://filescartografia.navarra… 2026-06-30
#>  7 007 Adiós                        https://filescartografia.navarra… 2026-06-30
#>  8 008 Aguilar de Codés             https://filescartografia.navarra… 2026-06-30
#>  9 009 Aibar / Oibar                https://filescartografia.navarra… 2026-06-30
#> 10 010 Altsasu / Alsasua            https://filescartografia.navarra… 2026-06-30
#> # ℹ 271 more rows