Use this function with caution. This function clears your cached data and configuration, specifically:
Deletes the CatastRoNav config directory (
rappdirs::user_config_dir("CatastRoNav", "R")).Deletes the
cache_dirdirectory.Deletes the values stored on
Sys.getenv("CATASTRONAV_CACHE_DIR").
Details
This is an overkill function that is intended to reset your status as if you had never installed or used CatastRoNav.
See also
Other cache utilities:
catrnav_set_cache_dir()
Examples
# Don't run this! It will modify your current state
# \dontrun{
catrnav_clear_cache(verbose = TRUE)
#> CatastRoNav cached data deleted: /tmp/RtmpzXUTTC/CatastRoNav
# }
Sys.getenv("CATASTRONAV_CACHE_DIR")
#> [1] ""